#[non_exhaustive]pub enum EnvHandle {
Global,
Base,
Empty,
Other,
}Expand description
An opaque handle to an environment.
rd-rds never models environment frames or enclosures: it only consumes
the wire bytes correctly and keeps the reference table aligned. All
non-singleton environments collapse to EnvHandle::Other.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Global
R_GlobalEnv.
Base
R_BaseEnv / R_BaseNamespace.
Empty
R_EmptyEnv.
Other
Any other environment/package/namespace. Its wire fields were decoded (to keep the stream and reference table in sync) and then discarded.