#[non_exhaustive]pub enum NativeEncodingSource {
Header(Arc<str>),
AssumedUtf8,
Unknown,
}Expand description
The source of native-encoding context used to interpret an R string.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Header(Arc<str>)
The stream header declared this native encoding name (format 3 only).
AssumedUtf8
The header carried no native encoding and the caller opted into
crate::NativeEncodingPolicy::AssumeUtf8.
Unknown
The header carried no native encoding and the caller made no assumption.