ViewError

Enum ViewError 

#[non_exhaustive]
pub enum ViewError { Missing { path: String, field: Option<String>, }, UnexpectedType { path: String, field: Option<String>, expected: &'static str, actual: &'static str, }, UnexpectedLength { path: String, field: Option<String>, expected: String, actual: usize, }, DuplicateName { path: String, field: Option<String>, }, InvalidStringEncoding { path: String, field: Option<String>, row: Option<usize>, column: Option<String>, }, InvalidDimensions { path: String, field: Option<String>, reason: String, }, InvalidPackageVersion { path: String, field: Option<String>, reason: String, }, }
A construction error from the typed installed-package metadata view.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Missing

Fields

path: String


UnexpectedType

Fields

path: String
expected: &'static str
actual: &'static str


UnexpectedLength

Fields

path: String
expected: String
actual: usize


DuplicateName

Fields

path: String


InvalidStringEncoding

Fields

path: String
column: Option<String>


InvalidDimensions

Fields

path: String
reason: String


InvalidPackageVersion

Fields

path: String
reason: String

Implementations

Source

impl ViewError

pub fn path(&self) -> String

Returns the logical location of the invalid value.

pub fn field(&self) -> Option<&str>

Returns the metadata field associated with the error, when there is one.

pub fn row(&self) -> Option<usize>

Returns row context when the error was caused by a matrix cell.

pub fn column(&self) -> Option<&str>

Returns column-name context when the error was caused by a matrix cell.