pub struct CharacterMatrix { /* private fields */ }Expand description
A validated, owned view of an R character matrix.
Matrix cells are stored in row-major order. An R NA cell is represented
by the inner None returned from CharacterMatrix::get, while an
out-of-bounds lookup is represented by the outer None.
Implementations
Sourceimpl CharacterMatrix
impl CharacterMatrix
Sourcepub fn from_object(object: &RObject) -> Result<Self, ViewError>
pub fn from_object(object: &RObject) -> Result<Self, ViewError>
Validates and copies an R character matrix.
Sourcepub fn get(&self, row: usize, column: usize) -> Option<Option<&str>>
pub fn get(&self, row: usize, column: usize) -> Option<Option<&str>>
Returns a cell, distinguishing an out-of-bounds lookup from an R NA.
Sourcepub fn row_name(&self, row: usize) -> Option<&str>
pub fn row_name(&self, row: usize) -> Option<&str>
Returns a row name, or None if it is absent, NA, or out of bounds.
Sourcepub fn column_name(&self, column: usize) -> Option<&str>
pub fn column_name(&self, column: usize) -> Option<&str>
Returns a column name, or None if it is absent, NA, or out of bounds.