#[non_exhaustive]pub enum MetadataField<T> {
Missing,
Present(T),
Invalid(ViewError),
UnsupportedSchema {
description: String,
},
}Expand description
The state of one known namespace metadata field.
Missing means that the field was absent from the metadata object.
Present includes an empty collection. Invalid means the field belongs
to the supported schema but contains invalid data. UnsupportedSchema
means that the shape was understood but is outside the supported profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations